# Xilinx Board

The {py:mod}`torii.platform.vendor.xilinx` module provides a base platform to support Xilinx devices with the [ISE], [Vivado], and [Symbiflow] toolchains.

```{eval-rst}

.. automodule:: torii_boards.xilinx.alchitry_au
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.arty_a7
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.arty_s7
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.arty_z7
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.atlys
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.ebaz4205
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.genesys2
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.kc705
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.kcu105
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.mega65
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.mercury
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.microzed_z010
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.microzed_z020
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.nexys4ddr
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.numato_mimas
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.sk_xc6slx9
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.te0714_03_50_2I
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.zturn_lite_z007s
	:members:
	:undoc-members:

.. automodule:: torii_boards.xilinx.zturn_lite_z010
	:members:
	:undoc-members:

```


[ISE]:　https://www.xilinx.com/products/design-tools/ise-design-suite.html
[Vivado]:　https://www.xilinx.com/products/design-tools/vivado.html
[Symbiflow]:　https://f4pga.readthedocs.io/projects/prjxray/en/latest/
